// Blur Motion
// Jorge Fuente-Alba
// PS 2.0
// 13-sample variable size directional Gaussian blur.

//#BORDER-MODE : prevent pixel influence from outside box area.
//#PARAM float blur 25 : Blur : amount of blur.
//#PARAM float angle 0 : Angle : angle of blur.


// Foreground texture
texture ForegroundTexture;

// Foreground sampler
sampler2D foreground = sampler_state {
    Texture = (ForegroundTexture);
    MinFilter = Linear;
    MagFilter = Linear;
    MipFilter = Linear;
};

// Pixel width in texels
float pixelWidth;
float pixelHeight;

//params
float blur;
float angle;

//blur kernel
float PixelKernel[13] =
{
    -0.92,
    -0.76,
    -0.6,
    -0.44,
    -0.28,
    -0.12,
     0.04,
     0.2,
     0.36,
     0.52,
     0.68,
     0.84,
     1,
};

//blur weights
static const float BlurWeights[13] = 
{
    0.002216,
    0.008764,
    0.026995,
    0.064759,
    0.120985,
    0.176033,
    0.199471,
    0.176033,
    0.120985,
    0.064759,
    0.026995,
    0.008764,
    0.002216,
};

// Effect function
float4 EffectProcess( float2 Tex : TEXCOORD0 ) : COLOR0
{
    // Apply surrounding pixels
    float4 color = 0;
    float2 samp = Tex;
    float realangle = (angle*3.1415)/180.0;
    float coefx = 0.5*blur*cos(realangle)* pixelWidth;
    float coefy = 0.5*blur*sin(realangle)* pixelHeight;
    for (int i = 0; i < 13; i++) {
        samp.x = Tex.x + (PixelKernel[i]*coefx);
        samp.y = Tex.y + (PixelKernel[i]*coefy);
        color += tex2D(foreground, samp.xy) * BlurWeights[i];
    }

    return color;
}

// ConstructEffect
technique ConstructEffect
{
    pass p0
    {
        VertexShader = null;
        PixelShader = compile ps_2_0 EffectProcess();
    }
}
